;;; v4test-mode.el -- Major mode for editing 4Test code (for QA Partner)
;; $Revision: 1.2 $ $Date: 1998/03/28 16:25:54 $ 

;; Author: Michael Richters <merlin@dimins.com>
;; Maintainer: Michael Richters
;; Keywords: qa, tools

;; Copyright (C) 1998 Michael Richters.

;; GNU Emacs is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; GNU Emacs is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;; This file is *NOT* part of GNU Emacs.

(defconst v4test-version "1.0"
  "4Test mode version number.")

;;; Commentary:

;; This module derives an editing mode from java-mode.  The derived mode
;; is for editing 4Test code.  (In the first release of this mode there's
;; very little specialized code; mostly you get a new mode-hook variable
;; ('v4test-mode-hook) and a new name ("4Test") for your emacs mode line.

;; To use v4test-mode, put this in your .emacs file:
;; (autoload 'v4test-mode "yourLispCodeDirectory/v4test-mode" "4Test mode" t nil)
;; (setq auto-mode-alist
;;       (append '(("\\.\\(t\\|inc\\)$" . v4test-mode)) auto-mode-alist))

(require 'cc-mode)


(define-derived-mode
  v4test-mode java-mode "4Test"
  "*Major mode for editing 4Test code (for Segue's QA Partner).
See the documentation for java-mode: v4test-mode is an extension of
java-mode.  Use the hook `v4test-mode-hook to execute code when
entering 4Test mode.
\\{v4test-mode-map}"
  )

(provide 'v4test-mode)

;; Change History
;;
;; $Log: v4test-mode.el,v $
;; Revision 1.2  1998/03/28 16:25:54  merlin
;; New version, that uses `define-derived-mode' to derive v4test-mode
;; from `java-mode'.  It now requires the `cc-mode' package to work
;; properly.  I have still not included font-lock support.
;;

